@@ -230,7 +230,7 @@ def _PyScript(env, target, source, command = "python $SOURCES", capture=None, ex
     basename = None
     if execute and tempdir == None:
         m = hashlib.sha1()
-        m.update(tuple(command_sig))
+        m.update("\n".join(command_sig))
         basename = os.path.join("temp", base64.b64encode(m.digest(), "+="), '')
     else: basename = tempdir
 
